/* eslint-disable eqeqeq */
import React, { useState, useEffect, Fragment } from 'react';
import '../../styles/profile/Profile.css';
import Button from '../utility/Button';
import ThreadList from '../thread/ThreadList';
import axios from 'axios';
import AuthService from '../../helpers/services/auth.service';
import { API_URL } from '../../config/keys';
import Pagination from '../Pagination';

export default function Profile(props) {
  const { params } = props.match;
  const profileUsername = params.user;
  const currentPage = params.pageNumber;

  const username = AuthService.getCurrentUsername();
  const isUser = profileUsername == username;

  const [user, setUser] = useState({
    id: '',
    name: '',
    username: '',
  });
  const [usersThreads, setUsersThreads] = useState([]);
  const [totalItems, setTotalItems] = useState(0);

  useEffect(() => {
    async function fetch(profileUsername) {
      // Fetch current user
      const getUser = await axios.get(
        `${API_URL}/users/name/${profileUsername}`
      );
      setUser(getUser?.data?.data);

      const responseThreads = await axios.get(
        `${API_URL}/threads/pages/user/${profileUsername}/?page=${currentPage}`
      );
      const { data } = responseThreads;
      setUsersThreads(data?.data);
      setTotalItems(data?.metadata?.total_data);
    }
    fetch(profileUsername);
  }, [currentPage, profileUsername]);

  function switchPage(pageNumber) {
    props.history.push(`/profile/${profileUsername}/page/${pageNumber}`);
    window.location.reload();
  }

  return (
    <div className="profileContainer">
      <div className="header">
        <h1>
          <b>Profile</b>
        </h1>
      </div>
      <div className="profileSection">
        <div className="userIcon">
          {user.picture == 'None' ? (
            <i className="far fa-user-circle" />
          ) : (
            <img alt="profile pic" src={user.picture} />
          )}
        </div>
        <h2 className="usernameProfile">
          <b>{user.username}</b>
        </h2>
        {isUser && (
          <Button text="Edit Profile" color="orange" url="profile/update" />
        )}
      </div>
      <div className="myThreadsSection">
        <div className="subHeaderMyThreads">
          <h3>
            <b>{isUser ? 'Your' : user.username}'s threads</b>
          </h3>
          {isUser && (
            <Button text="Create Thread" color="orange" url="create/thread" />
          )}
        </div>
        {totalItems == 0 ? (
          <p>
            {isUser
              ? "You don't have any threads. Why don't you make one?"
              : `${user.username} doesn't have any threads.`}
          </p>
        ) : (
          <Fragment>
            <ThreadList thread={usersThreads} />
            <div className="paginationContainer">
              <Pagination
                activePage={currentPage}
                totalItems={totalItems}
                switchPage={switchPage}
              />
            </div>
          </Fragment>
        )}
      </div>
    </div>
  );
}
