import axios from 'axios';
import React, { useState } from 'react';
import { useInput } from '../../helpers/hooks/input-hook';
import '../../styles/thread/Form.css';
import { API_URL } from '../../config/keys';
import AuthService, { authHeader } from '../../helpers/services/auth.service';

export default function FormCreateThread(props) {
  const {
    value: username,
    bind: bindUsername,
    reset: resetUsername,
  } = useInput(AuthService.getCurrentUsername());
  const [message, setMessage] = useState('');

  const back = () => {
    props.history.goBack();
  };

  const handleSubmit = async (event) => {
    event.preventDefault();
    try {
      await axios.put(
        `${API_URL}/users/update`,
        {
          user: {
            username: username,
          },
        },
        {
          headers: authHeader(),
        }
      );
      const currentUser = JSON.parse(localStorage.getItem('user'));
      currentUser.data.username = username;

      localStorage.setItem('user', JSON.stringify(currentUser));

      props.history.push(`/profile/${username}/1`);
    } catch (error) {
      setMessage('Username is already used by another User!');
    }
    resetUsername();
  };

  return (
    <div className="formComponentContainer">
      <div className="back" onClick={back}>
        <i className="fas fa-angle-left"></i>
        <h5>Back</h5>
      </div>
      <div className="header">
        <h1>
          <b>Edit Profile</b>
        </h1>
      </div>
      {message && (
        <div>
          <div className="alert alert-danger" role="alert">
            {message}
          </div>
        </div>
      )}
      <form onSubmit={handleSubmit}>
        <div className="formContainer">
          <label htmlFor="title">Username</label>
          <input
            type="text"
            className="username"
            name="username"
            placeholder="Your new Username"
            required="false"
            {...bindUsername}
          />
          <div className="buttonContainer">
            <input
              type="submit"
              className="buttonSubmit"
              value="Update Profile"
            />
          </div>
        </div>
      </form>
    </div>
  );
}
