/* eslint-disable eqeqeq */
import React, { useEffect, useState, Fragment } from 'react';
import axios from 'axios';
import SurveyCards from './SurveyCards';
import { API_URL } from '../../config/keys';
import Pagination from '../Pagination';
import { dummyData } from '../../helpers/data-util';
import { authHeader } from '../../helpers/services/auth.service';

export default function RecentSurveys(props) {
  const [surveys, setSurveys] = useState([]);
  const [totalItems, setTotalItems] = useState(0);

  const currentPage = props.pageNumber;

  if (currentPage != props.pageNumber) {
    window.location.reload();
  }

  useEffect(() => {
    const fetch = async () => {
      let data, metadata;
      try {
        const responseSurveys = await axios.get(
          `${API_URL}/surveys/pages/top/?page=${currentPage}`
        );
        ({ data, metadata } = responseSurveys.data);
      } catch (error) {
        data = dummyData();
      }
      setSurveys(data);
      setTotalItems(metadata.total_data);
    };
    fetch();
  }, [currentPage]);

  function switchPage(pageNumber) {
    props.history.push(`/survey/${pageNumber}`);
    window.location.reload();
  }

  async function deleteSurvey(id) {
    setSurveys(surveys.filter(survey => survey.id !== id));
    await axios.delete(
      `${API_URL}/surveys/${id}`,
      { headers: authHeader() }
    );
  }

  return (
    <div className="recentSurveys">
      {totalItems == undefined || totalItems == 0 ? (
        <div className="noSurveysMessage">
          <p>There is no surveys yet.</p>
        </div>
      ) : (
        <Fragment>
          <SurveyCards survey={surveys} deleteSurvey={deleteSurvey} />
          <div className="paginationContainer">
            <Pagination
              activePage={currentPage}
              totalItems={totalItems}
              switchPage={switchPage}
            />
          </div>
        </Fragment>
      )}
    </div>
  );
}
