import React, { useEffect, useState } from 'react';
import axios from 'axios';
import { API_URL } from '../../config/keys';
import { authHeader } from '../../helpers/services/auth.service';
import ShowDiagram from './diagram/ShowDiagram';
import { diagram5Color } from '../../helpers/color';

export default function ViewAnswer(props) {
    const { survey } = props;
    const { id, question } = props.question;
    const [answer, setAnswer] = useState([]);
    const total = answer.map(val => val.answer_count).reduce((a,b) => a+b, 0);

    useEffect(() => {
        async function getAnswer() {
            const answer = (await axios.get(
                `${API_URL}/answers/${survey}/${id}`,
                { headers: authHeader() }
            ))?.data;
            const existingAnswer = answer.map(val => val.answer);
            const emptyAnswer = ['1','2','3','4','5'].filter(val => !existingAnswer.includes(val))
                .map(val => { return { answer:val, answer_count: 0 }; });
            setAnswer(answer.concat(emptyAnswer).sort((a, b) => parseInt(a.answer) - parseInt(b.answer)));
        }
        getAnswer();
        // eslint-disable-next-line
    }, [id]);

    const styleDiagram = {
        display: 'flex',
    };

    const styleLabel = {
        marginRight: '24px',
    }

    return (
        <div>
            <div>
                <h5>{question}</h5>
            </div>
            <div style={styleDiagram}>
                <div style={styleLabel}>
                    { answer.map((val, idx) => <ColorLabel key={idx} label={val.answer} amount={val.answer_count} total={total} idx={idx}/>) }
                </div>
                <div>
                    <ShowDiagram data={answer}/>
                </div>
            </div>
        </div>
    )
}

function ColorLabel(props) {
    const { label, amount, total } = props;
    const style = {
        backgroundColor: `#${diagram5Color[label]}`,
        marginLeft: '24px',
        paddingLeft: '48px',
        marginRight: '12px',
    };
    const percent = total !== 0 ? amount / total * 100 : 0;

    return (
        <div style={{ width:'fit-content' }}>
            <span>Answer: <strong>{label}</strong></span>
            <span style={style}>&nbsp;</span>
            <span>Amount: <strong>{amount}</strong>&nbsp;({percent.toFixed(2)}%)</span>
        </div>
    )
}
