import axios from 'axios';
import React, { useState, useEffect } from 'react';
import { authHeader } from '../../helpers/services/auth.service';
import { API_URL } from '../../config/keys';
import '../../styles/thread/Form.css';
import { loggedIn } from '../../helpers/services/auth.service';

const likert = [...Array(5).keys()].map(i => i + 1);

export default function ViewSurvey(props) {
  const { history } = props;
  const { survey } = props.match.params;
  const [title, setTitle] = useState('');
  const [questions, setQuestions] = useState([]);
  const [answers, setAnswers] = useState({});

  useEffect(() => {

    if (!loggedIn) {
      window.alert("Anda belum login");
      history.push('');
    }
    else {
      let questionList;
      async function getSurveyData() {
        const surveyData = (await axios.get(
          `${API_URL}/surveys/show_questions/${survey}`,
          { headers: authHeader() }
        ))?.data;
        const title = surveyData?.title;
        setTitle(title);
        questionList = surveyData?.questions;
        setQuestions(questionList);
      }

      getSurveyData().then(() => {
        let newAnswers = {}
        questionList.forEach(({ id }) => {
          newAnswers[id] = { question_id: id };
        })
        setAnswers(newAnswers);
      })
    }
  }, [survey, history]);

  const handleSubmit = async (event) => {
    event.preventDefault();
    try {
      Object.entries(answers).forEach(async ([_, answer]) => {
        await axios.post(
          `${API_URL}/answers`,
          { answer: answer },
          { headers: authHeader() }
        );
      })
      window.alert("Submitted your answer successfully");
      history.push('');
    } catch (error) {
      window.alert("Error submitting your answer");
    }
  };

  return (
    <div className="formComponentContainer">
      <div className="header">
        <h1><b>{title}</b></h1>
      </div>
      <div><p>1 = Sangat Tidak Setuju</p><p>5 = Sangat Setuju</p></div>
      <form onSubmit={handleSubmit}>
        {questions.map(({ id, question }, idx) =>
          <Question id={id} question={question} idx={idx} key={idx} />
        )}
        <br />
        {loggedIn && <input type="submit" className="btn btn-orange" />}
      </form>
    </div>
  );

  function updateAnswer(id, answer) {
    let newAnswers = answers;
    newAnswers[id]['answer'] = answer;
    setAnswers(newAnswers);
  }

  function Question({ id, question, idx }) {
    return <>
      <br />
      <h5>{idx + 1}. {question}</h5>
      <fieldset className="btn-group btn-group-toggle"
        onChange={(event) => updateAnswer(id, event.target.value)}
      >
        {likert.map((i) =>
          <label key={i}>
            <input type="radio" id={i} name={idx} value={i} required /> {i}
          </label>
        )}
       
      </fieldset>
    
    </>
  }
}
