import React from 'react';
import { diagram5Color } from '../../../helpers/color';

export default function CircleDiagram(props) {
    const { rawData, radius, cx, cy } = props;
    const data = rawData.map(val => val.answer_count);
    const strokeWidth = 2*radius;
    const perimeter = 2 * Math.PI * radius;
    const cumulativeSum = data.map((val, idx) => data.slice(0,idx).reduce(add, 0));
    const total = cumulativeSum.slice(-1).pop() + data.slice(-1).pop();
    const transform = `translate(${cx} ${cy})`;

    return (
        <g transform={transform}>
            { total && rawData.map((val, idx) =>
                <CircleSector key={idx} radius={radius} val={val.answer_count}
                    width={strokeWidth} total={total} perimeter={perimeter}
                    offset={cumulativeSum[idx]} color={diagram5Color[val.answer]}
                />)
            }
        </g>
    );
}

function CircleSector(props) {
    const { radius, color, width, val, total, perimeter, offset } = props;
    const colorCode = `#${color}`;
    const length = val / total * perimeter;
    const dashArray = `${length} ${perimeter - length}`;
    const transform = `rotate(${offset / total * 360})`

    return (
        <circle fill='transparent' r={radius} stroke={colorCode} strokeWidth={width}
            strokeDasharray={dashArray} transform={transform}
        />
    )
}

function add(a,b) { return a+b; }
