import axios from 'axios';
import React, { useState, useEffect } from 'react';
import { useInput } from '../../helpers/hooks/input-hook';
import { authHeader, userData } from '../../helpers/services/auth.service';
import { API_URL, FAAS_URL } from '../../config/keys';
import '../../styles/thread/Form.css';

export default function ListThreads(props) {
  const { history } = props;

  const back = () => {
    history.goBack();
  };

  const redirect = (path) => {
    history.push(path);
  };

  const { value: title, bind: bindTitle, reset: resetTitle } = useInput('');
  const { value: body, bind: bindBody, reset: resetBody } = useInput('');
  const { value: topicId, bind: bindTopicId, reset: resetTopicId } = useInput(
    0
  );

  const [listTopic, setlistTopic] = useState([]);
  const [message, setMessage] = useState('');

  useEffect(() => {
    async function getListTopic() {
      const allTopic = await (await axios.get(`${API_URL}/topics`))?.data?.data;
      setlistTopic(allTopic);
    }
    getListTopic();
  }, []);

  const handleSubmit = async (event) => {
    event.preventDefault();
    try {
      console.log(body);
      const thisThread = await axios.post(
        `${API_URL}/threads`,
        {
          thread: {
            content: body,
            points: 0,
            title: title,
            topic_id: topicId,
          },
        },
        {
          headers: authHeader(),
        }
      );

      const discordMessage = userData();
      discordMessage.title = title;
      axios
        .post(`${FAAS_URL}/notifyDiscord`, discordMessage);

      const { data } = thisThread?.data;
      redirect(`/topic/${data?.topic_name}/${data?.id}/page/1`);
    } catch (error) {
      setMessage("Thread's title already exist in the selected topic");
    }
    resetBody();
    resetTitle();
    resetTopicId();
  };

  return (
    <div className="formComponentContainer">
      <div className="back" onClick={back}>
        <i className="fas fa-angle-left"></i>
        <h5>Back</h5>
      </div>
      <div className="header">
        <h1>
          <b>Create a Thread</b>
        </h1>
      </div>
      <div className="formSection">
        <div>
          {message && (
            <div>
              <div className="alert alert-danger" role="alert">
                <p>{message}</p>
              </div>
            </div>
          )}
          <form onSubmit={handleSubmit}>
            <div className="formContainer">
              <label for="title">Title</label>
              <input
                type="text"
                className="title"
                name="title"
                placeholder="Your thread's title"
                required="false"
                {...bindTitle}
              />
              <label>Topic</label>
              <select
                className="topic"
                name="topic"
                required="false"
                {...bindTopicId}
              >
                <option value="" />
                {listTopic.map((topic) => (
                  <option value={topic.id}>{topic.name}</option>
                ))}
              </select>
              <label for="body">Body</label>
              <textarea
                className="body"
                name="body"
                placeholder="Your thread's body"
                required="false"
                {...bindBody}
              />
              <div className="buttonContainer">
                <input
                  type="submit"
                  className="buttonSubmit"
                  value="Create Thread"
                />
              </div>
            </div>
          </form>
        </div>
      </div>
    </div>
  );
}
