/* eslint-disable eqeqeq */
import React, { useEffect, useState, Fragment } from 'react';
import axios from 'axios';
import ThreadList from './ThreadList';
import { API_URL } from '../../config/keys';
import Pagination from '../Pagination';

export default function RecentThreads(props) {
  const [threads, setThreads] = useState([]);
  const [totalItems, setTotalItems] = useState(0);

  const currentPage = props.pageNumber;

  if (currentPage != props.pageNumber) {
    window.location.reload();
  }

  useEffect(() => {
    const fetch = async () => {
      const responseThreads = await axios.get(
        `${API_URL}/threads/pages/recent/?page=${currentPage}`
      );
      const { data } = responseThreads;
      setThreads(data?.data);
      setTotalItems(data?.metadata?.total_data);
    };
    fetch();
  }, [currentPage]);

  function switchPage(pageNumber) {
    props.history.push(`/page/${pageNumber}`);
    window.location.reload();
  }

  return (
    <div className="recentThreads">
      {totalItems == undefined || totalItems == 0 ? (
        <div className="noThreadsMessage">
          <p>There is no threads yet.</p>
        </div>
      ) : (
        <Fragment>
          <ThreadList thread={threads} />
          <div className="paginationContainer">
            <Pagination
              activePage={currentPage}
              totalItems={totalItems}
              switchPage={switchPage}
            />
          </div>
        </Fragment>
      )}
    </div>
  );
}
