/* eslint-disable eqeqeq */
import React, { useState, useEffect, useCallback } from 'react';
import '../../styles/thread/Thread.css';
import CommentList from './CommentList';
import Post from './Post';
import { useInput } from '../../helpers/hooks/input-hook';
import axios from 'axios';
import AuthService, {
  authHeader,
  loggedIn,
} from '../../helpers/services/auth.service';
import { API_URL } from '../../config/keys';
import Pagination from '../Pagination';

export default function Thread(props) {
  const currentUserId = AuthService.getCurrentUserId();
  const redirect = (url) => {
    props.history.push(url);
  };

  const [thread, setThread] = useState({
    content: '',
    id: '',
    points: 0,
    title: '',
    topic_id: '',
    user_id: '',
    updated_at: '',
    inserted_at: '',
    username: '',
  });

  const [comment, setComment] = useState([
    {
      id: '',
      message: '',
      points: 0,
      thread_id: '',
      user_id: '',
      updated_at: '',
      inserted_at: '',
      username: '',
    },
  ]);

  const { params } = props.match;
  const topicParm = params.topic;
  const threadParm = params.thread;
  const currentPage = params.pageNumber;

  const { value: input, bind: bindInput, reset: resetInput } = useInput('');
  const [totalComments, setTotalComments] = useState(0);

  const refreshComment = useCallback(() => {
    const fetch = async () => {
      const responseComment = await axios.get(
        `${API_URL}/post/pages/thread/${threadParm}/?page=${currentPage}`
      );
      const { data } = responseComment;
      setComment(data?.data);
      setTotalComments(data?.metadata?.total_data);
    };
    fetch();
  }, [threadParm, currentPage]);

  useEffect(() => {
    const fetch = async () => {
      const responseThread = await axios.get(
        `${API_URL}/threads/${threadParm}`
      );
      setThread(responseThread?.data?.data);
      refreshComment();
    };
    fetch();
  }, [threadParm, refreshComment, currentUserId, thread]);

  const handleSubmit = async (event) => {
    event.preventDefault();

    try {
      await axios.post(
        `${API_URL}/post`,
        {
          post: {
            message: input,
            points: 0,
            thread_id: threadParm,
            user_id: localStorage.getItem('id'),
          },
        },
        {
          headers: authHeader(),
        }
      );
      refreshComment();
    } catch (error) {}
    resetInput();
  };

  function switchPage(pageNumber) {
    props.history.push(`/topic/${topicParm}/${threadParm}/page/${pageNumber}`);
    window.location.reload();
  }

  return (
    <div className="threadContainer">
      <div className="thread_section">
        <Post type="thread" content={thread} redirect={redirect} />
      </div>

      {loggedIn && (
        <div className="addCommentSection">
          <h3>Write a Comment</h3>
          <form onSubmit={handleSubmit}>
            <div className="commentFormContainer">
              <textarea
                className="commentBox"
                placeholder="Write your comment here"
                required="false"
                {...bindInput}
              />
              <div>
                <button
                  className="submitComment addCommentButton"
                  type="submit"
                >
                  Post Comment
                </button>
              </div>
            </div>
          </form>
        </div>
      )}
      <h2 className="commentText">Comments</h2>

      {totalComments == 0 ? (
        <div className="noCommentLabel">
          <p>There are no comments yet.</p>
        </div>
      ) : (
        <div>
          <CommentList
            comment={comment}
            thread_className={threadParm}
            topic_className={topicParm}
          />
          <div className="paginationContainer">
            <Pagination
              activePage={currentPage}
              totalItems={totalComments}
              switchPage={switchPage}
            />
          </div>
        </div>
      )}
    </div>
  );
}
