/* eslint-disable eqeqeq */
import React, { useEffect, useState } from 'react';
import axios from 'axios';
import { Link } from 'react-router-dom';
import { API_URL } from '../../config/keys';
import '../../styles/topic/TopicList.css';
import Button from '../utility/Button';
import { loggedIn, isAdmin } from '../../helpers/services/auth.service';

export default function TopicList(props) {
  const [topics, setTopics] = useState([]);

  useEffect(() => {
    const fetch = async () => {
      const response = await axios.get(`${API_URL}/topics`);
      setTopics(response?.data?.data);
    };
    fetch();
  }, []);

  return (
    <div className="topicContainer">
      <div className="topicHeader">
        <h1>Topic List</h1>
        {loggedIn && isAdmin && (
          <Button text="Create Topic" color="orange" url="create/topic" />
        )}
      </div>
      {topics.length == 0 && (
        <div className="noTopic">
          <p>There is no topics yet.</p>
        </div>
      )}
      {topics.length != 0 && (
        <div className="topics">
          <div className="topicCards">
            {topics.map((value) => (
              <div className="topicCardContainer">
                <Link
                  to={`topic/${value.name}/page/1`}
                  style={{ textDecoration: 'none' }}
                >
                  <div className="topicCard">
                    <div className="topicCardHeader">
                      <h2 className="topicTitle">{value.name}</h2>
                    </div>
                  </div>
                </Link>
              </div>
            ))}
          </div>
        </div>
      )}
    </div>
  );
}
