import '../styles/App.css';
import Thread from '../components/thread/Thread';
import Topic from '../components/topic/Topic';
import Navbar from '../components/utility/Navbar';
import Profile from '../components/profile/Profile';
import ListThreads from '../components/thread/ListThreads';
import ListSurveys from '../components/survey/ListSurveys';
import CreateThread from '../components/thread/CreateThread';
import LoginForm from '../components/LoginForm';
import TopicList from '../components/topic/TopicList';
import CreateTopicForm from '../components/topic/CreateTopicForm';
import Search from '../components/Search';
import EditThread from '../components/thread/EditThread';
import Footer from '../components/utility/Footer';
import UpdateProfileForm from '../components/profile/UpdateProfileForm.jsx';
import EditComment from '../components/thread/EditComment';
import CreateNumber from '../components/survey/CreateNumber';
import CreateSurvey from '../components/survey/CreateSurvey';
import ViewSurvey from '../components/survey/ViewSurvey';
import ViewSurveyAnswer from '../components/survey/ViewSurveyAnswer';
import {
  BrowserRouter as Router,
  Route,
  Redirect,
  Switch,
} from 'react-router-dom';

function App() {
  return (
    <Router>
      <Navbar />
      <Switch>
        <Route
          exact
          path="/page/:pageNumber"
          component={(props) => (
            <ListThreads
              isRecent={true}
              pageNumber={props.match.params.pageNumber}
              history={props.history}
            />
          )}
        />
        <Route
          exact
          path="/top/page/:pageNumber"
          component={(props) => (
            <ListThreads
              isRecent={false}
              pageNumber={props.match.params.pageNumber}
              history={props.history}
            />
          )}
        />
        <Route
          exact
          path="/survey/:pageNumber"
          component={(props) => (
            <ListSurveys
              isRecent={true}
              pageNumber={props.match.params.pageNumber}
              history={props.history}
            />
          )}
        />
        <Route
          exact
          path="/top/survey/:pageNumber"
          component={(props) => (
            <ListSurveys
              isRecent={false}
              pageNumber={props.match.params.pageNumber}
              history={props.history}
            />
          )}
        />
        <Route exact path="/topic" component={TopicList} />
        <Route exact path="/profile/:user/page/:pageNumber" component={Profile} />
        <Route exact path="/login" component={LoginForm} />
        <Route exact path="/create/topic" component={CreateTopicForm} />
        <Route exact path="/create/thread" component={CreateThread} />
        <Route exact path="/create/number" component={CreateNumber} />
        <Route exact path="/create/survey" component={CreateSurvey} />
        <Route exact path="/search/:input/page/:pageNumber" component={Search} />
        <Route
          exact
          path="/topic/:topic/:thread/page/:pageNumber"
          component={Thread}
        />
        <Route exact path="/topic/:topic/page/:pageNumber" component={Topic} />
        <Route exact path="/threads" component={ListThreads} />
        <Route exact path="/thread/edit/:thread" component={EditThread} />
        <Route exact path="/profile/update" component={UpdateProfileForm} />
        <Route exact path="/comment/edit/:comment" component={EditComment} />
        <Route exact path="/surveys" component={ListSurveys} />
        <Route exact path="/survey/:survey/fill" component={ViewSurvey} />
        <Route exact path="/survey/:survey/answer" component={ViewSurveyAnswer} />
        <Redirect exact from="" to="survey/1" />
      </Switch>
      <Footer />
    </Router>
  );
}

export default App;
